summaryrefslogtreecommitdiffstats
path: root/ksirc/puke/pobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/puke/pobject.h')
-rw-r--r--ksirc/puke/pobject.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/ksirc/puke/pobject.h b/ksirc/puke/pobject.h
index 8e5c7c5a..d27fab58 100644
--- a/ksirc/puke/pobject.h
+++ b/ksirc/puke/pobject.h
@@ -5,7 +5,7 @@ class PObject;
class PukeController;
class CreateArgs;
-#include <qobject.h>
+#include <tqobject.h>
#include "pmessage.h"
@@ -26,18 +26,18 @@ public:
/**
* name of the widget which was fetched from kSirc, this has to be set explicitly
*/
- QObject *fetchedObj;
+ TQObject *fetchedObj;
};
class PObject : public QObject
{
Q_OBJECT
public:
- PObject(QObject *parent = 0, const char *name = 0);
+ PObject(TQObject *parent = 0, const char *name = 0);
virtual ~PObject();
/**
* Creates a new QObject and returns a PObject
*/
static PObject *createWidget(CreateArgs &ca);
@@ -50,12 +50,12 @@ class PObject : public QObject
/**
* Sets the current opbect
*/
- virtual void setWidget(QObject *w);
+ virtual void setWidget(TQObject *w);
/**
* Returns the current object
*/
- virtual QObject *widget();
+ virtual TQObject *widget();
/**
* Sets the window id
@@ -90,7 +90,7 @@ class PObject : public QObject
/**
* Returns error description
*/
- QString error() {
+ TQString error() {
m_hasError = false;
return m_error;
}
@@ -117,16 +117,16 @@ class PObject : public QObject
protected:
PukeController *controller();
- void errorInvalidSet(QObject *_w);
+ void errorInvalidSet(TQObject *_w);
private:
- QObject *obj;
+ TQObject *obj;
PukeController *pController;
widgetId wI;
bool manualTerm;
bool deleteAble;
- QString m_error;
+ TQString m_error;
bool m_hasError;
};
@@ -26,18 +26,18 @@ public:
virtual ~PObject();
/**
- * Creates a new QObject and returns a PObject
+ * Creates a new TQObject and returns a PObject
*/
static PObject *createWidget(CreateArgs &ca);